==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Layer/ts/Layer_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+54"/>
        <source>&amp;Layer</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
Wars&amp;twa
Użyj bieżącej &amp;warstwy</translatorcomment>
        <translation type="unfinished">Wars&amp;twa</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+136"/>
        <source>Leading or trailing spaces.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Nazwa warstwy jest pusta.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Warstwa już istnieje.</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Danych warstwy</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Nazwa warstwy:</translatorcomment>
        <translation type="unfinished">Nazwa warstwy:</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Pen</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Otwieranie ostatniego pliku...
Otwieranie ostatniego pliku
Otwieranie przerwane</translatorcomment>
        <translation type="unfinished">Pióro</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kolor &amp;siatki:
Kolor siatki:
Kolor &amp;meta-siatki:</translatorcomment>
        <translation type="unfinished">Kolor:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Lineweight:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Szerokość linii:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Linetype:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Rodzaj linii:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Layer/ts/Layer_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Layer</name>
    <message>
        <location filename="../Layer.js" line="+66"/>
        <source>Layer Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show layer tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Layer</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
Wars&amp;twa
Użyj bieżącej &amp;warstwy</translatorcomment>
        <translation type="unfinished">Wars&amp;twa</translation>
    </message>
</context>
<context>
    <name>LayerDialog</name>
    <message>
        <location filename="../LayerDialog.js" line="+176"/>
        <source>Leading or trailing spaces.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Layer name is empty.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Nazwa warstwy jest pusta.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Layer already exists.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Warstwa już istnieje.</translation>
    </message>
    <message>
        <location filename="../LayerDialog.ui" line="+17"/>
        <source>Layer Data</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Danych warstwy</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Layer name:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Nazwa warstwy:</translatorcomment>
        <translation type="unfinished">Nazwa warstwy:</translation>
    </message>
    <message>
        <source>Pen</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Otwieranie ostatniego pliku...
Otwieranie ostatniego pliku
Otwieranie przerwane</translatorcomment>
        <translation type="obsolete">Pióro</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Attributes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kolor &amp;siatki:
Kolor siatki:
Kolor &amp;meta-siatki:</translatorcomment>
        <translation type="unfinished">Kolor:</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Lineweight:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Szerokość linii:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Linetype:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Rodzaj linii:</translation>
    </message>
</context>
</TS>
